@@ -1,13 +1,12 @@
 from datetime import date
 
-from django.conf import settings
 from django.db import models
 from django.forms import ValidationError
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
-from .choices import HardwareKindChoices, InventoryStatusChoices
-from .utils import get_prechange_field, get_status_for
+from .choices import HardwareKindChoices, AssetStatusChoices
+from .utils import get_prechange_field, get_plugin_setting, get_status_for
 
 
 class Asset(NetBoxModel):
@@ -54,7 +53,7 @@ class Asset(NetBoxModel):
     #
     status = models.CharField(
         max_length=30,
-        choices=InventoryStatusChoices,
+        choices=AssetStatusChoices,
         help_text='Asset lifecycle status',
     )
 
@@ -279,7 +278,7 @@ class Asset(NetBoxModel):
         """ If assigning as device, module or inventoryitem set serial and
             asset_tag on it. Also remove them if unasigning.
         """
-        if not settings.PLUGINS_CONFIG['netbox_inventory']['sync_hardware_serial_asset_tag']:
+        if not get_plugin_setting('sync_hardware_serial_asset_tag'):
             return None
         old_hw = get_prechange_field(self, self.kind)
         new_hw = getattr(self, self.kind)
@@ -321,7 +320,7 @@ class Asset(NetBoxModel):
         return reverse('plugins:netbox_inventory:asset', args=[self.pk])
     
     def get_status_color(self):
-        return InventoryStatusChoices.colors.get(self.status)
+        return AssetStatusChoices.colors.get(self.status)
 
     def __str__(self):
         return f'{self.hardware_type} {self.serial}'
